==> zio-aws-sagemaker_2.12-5.19.31.5-sources.jar: zio/aws/sagemaker/model/ListHubsResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListHubsResponse(
    hubSummaries: Iterable[zio.aws.sagemaker.model.HubInfo],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListHubsResponse = {
    import ListHubsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
      .builder()
      .hubSummaries(hubSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListHubsResponse.ReadOnly =
    zio.aws.sagemaker.model.ListHubsResponse.wrap(buildAwsValue())
}
object ListHubsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListHubsResponse =
      zio.aws.sagemaker.model.ListHubsResponse(
        hubSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def hubSummaries: List[zio.aws.sagemaker.model.HubInfo.ReadOnly]
    def nextToken: Optional[NextToken]
    def getHubSummaries
        : ZIO[Any, Nothing, List[zio.aws.sagemaker.model.HubInfo.ReadOnly]] =
      ZIO.succeed(hubSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ) extends zio.aws.sagemaker.model.ListHubsResponse.ReadOnly {
    override val hubSummaries: List[zio.aws.sagemaker.model.HubInfo.ReadOnly] =
      impl
        .hubSummaries()
        .asScala
        .map { item =>
          zio.aws.sagemaker.model.HubInfo.wrap(item)
        }
        .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ): zio.aws.sagemaker.model.ListHubsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-6.20.56.2-sources.jar: zio/aws/sagemaker/model/ListHubsResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class ListHubsResponse(
    hubSummaries: Iterable[zio.aws.sagemaker.model.HubInfo],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListHubsResponse = {
    import ListHubsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
      .builder()
      .hubSummaries(hubSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListHubsResponse.ReadOnly =
    zio.aws.sagemaker.model.ListHubsResponse.wrap(buildAwsValue())
}
object ListHubsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListHubsResponse =
      zio.aws.sagemaker.model.ListHubsResponse(
        hubSummaries.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def hubSummaries: List[zio.aws.sagemaker.model.HubInfo.ReadOnly]
    def nextToken: Optional[NextToken]
    def getHubSummaries
        : ZIO[Any, Nothing, List[zio.aws.sagemaker.model.HubInfo.ReadOnly]] =
      ZIO.succeed(hubSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ) extends zio.aws.sagemaker.model.ListHubsResponse.ReadOnly {
    override val hubSummaries: List[zio.aws.sagemaker.model.HubInfo.ReadOnly] =
      impl
        .hubSummaries()
        .asScala
        .map { item =>
          zio.aws.sagemaker.model.HubInfo.wrap(item)
        }
        .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListHubsResponse
  ): zio.aws.sagemaker.model.ListHubsResponse.ReadOnly = new Wrapper(impl)
}
